@@ -186,7 +186,7 @@
              :dev {:resource-paths ["dummy-data"]
                    :dependencies [[clj-stacktrace "0.2.4"]]}
              ;; activated automatically during uberjar
-             :uberjar {:aot :all}
+             :uberjar {:aot [entry.point.ns]}
              ;; activated automatically in repl task
              :repl {:plugins [[cider/cider-nrepl "0.7.1"]]}}
   ;; Load these namespaces from within Leiningen to pick up hooks from them.
@@ -267,8 +267,10 @@
   ;; These namespaces will be AOT-compiled. Needed for gen-class and
   ;; other Java interop functionality. Put a regex here to compile all
   ;; namespaces whose names match. If you only need AOT for an uberjar
-  ;; gen-class, put `:aot :all` in the :uberjar profile and see :target-path for
-  ;; how to enable profile-based target isolation.
+  ;; gen-class, put `:aot [entry.point.ns]` in the :uberjar profile and see
+  ;; :target-path for how to enable profile-based target isolation.
+  ;; Putting :all here will AOT-compile everything, but this can cause issues
+  ;; with certain uses of protocols and records.
   :aot [org.example.sample]
   ;; Forms to prepend to every form that is evaluated inside your project.
   ;; Allows working around the Gilardi Scenario: http://technomancy.us/143
@@ -380,9 +382,14 @@
                  ;; Skip's the default requires and printed help message.
                  :skip-default-init false
                  ;; Customize the socket the repl task listens on and
-                 ;; attaches to.
-                 :host "0.0.0.0"
-                 :port 4001
+                 ;; attaches to.  Specify either a filesystem :socket
+                 ;; (where the parent directory should be used to
+                 ;; control access since POSIX doesn't require
+                 ;; respecting the socket permissions):
+                 :socket "/path/to/the/socket"
+                 ;; or a network :host and/or :port
+                 ;;   :host "0.0.0.0"
+                 ;;   :port 4001
                  ;; If nREPL takes too long to load it may timeout,
                  ;; increase this to wait longer before timing out.
                  ;; Defaults to 30000 (30 seconds)
@@ -518,7 +525,7 @@
   ;; Dictate which git branches deploys should be allowed from. When set,
   ;; `lein deploy` will only work from the git branches included and will
   ;; abort otherwise.
-  :deploy-branches ["master"]
+  :deploy-branches ["main"]
 
 ;;; Artifact Classifers Installation
   ;; Option to install classified maven artifacts. A map where keys
