@@ -1,4 +1,4 @@
-(defproject nrepl "0.8.3"
+(defproject nrepl "0.9.0"
   :description "nREPL is a Clojure *n*etwork REPL."
   :url "https://nrepl.org"
   :license {:name "Eclipse Public License"
@@ -11,7 +11,7 @@
   :javac-options ["-target" "8" "-source" "8"]
 
   :aliases {"bump-version" ["change" "version" "leiningen.release/bump-version"]
-            "test-all" ["with-profile" "+1.7:+1.8:+1.9:+1.10:+fastlane" "test"]
+            "test-all" ["with-profile" "+1.7:+1.8:+1.9:+1.10:+fastlane:+junixsocket" "test"]
             "docs" ["with-profile" "+maint" "run" "-m" "nrepl.impl.docs" "--file"
                     ~(clojure.java.io/as-relative-path
                       (clojure.java.io/file "doc" "modules" "ROOT" "pages" "ops.adoc"))]
@@ -40,12 +40,15 @@
                     ;; TODO: replicate koacha's version filter logic here
                     :test-selectors {:default (complement :min-java-version)}
                     :aliases {"test" "test2junit"}}
+             :junixsocket {:jvm-opts ["-Dnrepl.test.junixsocket=true"]
+                           :dependencies [[com.kohlschutter.junixsocket/junixsocket-core "2.3.2"]]}
+             :clj-kondo {:dependencies [[clj-kondo "2021.10.19"]]}
              ;; Clojure versions matrix
-             :provided {:dependencies [[org.clojure/clojure "1.10.1"]]}
+             :provided {:dependencies [[org.clojure/clojure "1.10.2"]]}
              :1.7 {:dependencies [[org.clojure/clojure "1.7.0"]]}
              :1.8 {:dependencies [[org.clojure/clojure "1.8.0"]]}
              :1.9 {:dependencies [[org.clojure/clojure "1.9.0"]]}
-             :1.10 {:dependencies [[org.clojure/clojure "1.10.1"]]
+             :1.10 {:dependencies [[org.clojure/clojure "1.10.2"]]
                     :source-paths ["src/spec"]}
              :master {:repositories [["snapshots"
                                       "https://oss.sonatype.org/content/repositories/snapshots"]]
@@ -61,20 +64,25 @@
 
              ;; CI tools
              :cloverage [:test
-                         {:plugins [[lein-cloverage "1.1.2"]]
-                          :dependencies [[cloverage "1.1.2"]]
+                         {:plugins [[lein-cloverage "1.2.2"]]
+                          :dependencies [[cloverage "1.2.2"]]
                           :cloverage {:codecov? true
                                       ;; Cloverage can't handle some of the code
                                       ;; in this project
                                       :test-ns-regex [#"^((?!nrepl.sanity-test).)*$"]}}]
 
-             :cljfmt {:plugins [[lein-cljfmt "0.6.1"]]
+             :cljfmt {:plugins [[lein-cljfmt "0.8.0"]]
                       :cljfmt {:indents {as-> [[:inner 0]]
                                          with-debug-bindings [[:inner 0]]
                                          merge-meta [[:inner 0]]
+                                         returning [[:inner 0]]
                                          testing-dynamic [[:inner 0]]
                                          testing-print [[:inner 0]]}}}
 
              :eastwood [:test
-                        {:plugins [[jonase/eastwood "0.3.4"]]
-                         :eastwood {:config-files ["eastwood.clj"]}}]})
+                        {:plugins [[jonase/eastwood "0.9.9"]]
+                         :global-vars {*warn-on-reflection* true}
+                         :eastwood {:config-files ["eastwood.clj"]
+                                    :ignored-faults {:non-dynamic-earmuffs {nrepl.middleware.load-file true}
+                                                     :unused-ret-vals {nrepl.util.completion-test true}
+                                                     :reflection {nrepl.socket.dynamic true}}}}]})
